Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var All = []string{
"alienvault",
"anubis",
"bufferover",
"cebaidu",
"certspotterv0",
"chaos",
"crtsh",
"hackertarget",
"rapiddns",
"riddler",
"sublist3r",
"threatcrowd",
"threatminer",
"urlscan",
"wayback",
"ximcx",
}
All contains the list of all sources used by default.
Functions ¶
Types ¶
type Keys ¶
type Keys struct {
Chaos string `json:"chaos"`
}
Keys contains the current API Keys we have in store
type Session ¶
type Session struct {
// Extractor is the regex for subdomains created for each domain
Extractor *regexp.Regexp
// Keys is the API keys for the application
Keys *Keys
// Client is the current http client
Client *fasthttp.Client
}
Session is the option passed to the source, an option is created uniquely for eac source.
func NewSession ¶
NewSession creates a new session object for a domain
type Source ¶
type Source interface {
// Run takes a domain as argument and a session object
// which contains the extractor for subdomains, http client
// and other stuff.
Run(string, *Session) chan Subdomain
// Name returns the name of the source
Name() string
}
Source is an interface inherited by each passive source
Click to show internal directories.
Click to hide internal directories.