Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Conf ¶
type Conf struct {
// Version indicates the version of subfinder installed.
Version string `yaml:"version"`
// Sources contains a list of sources to use for enumeration
Sources []string `yaml:"sources,omitempty"`
Keys struct {
Chaos []string `yaml:"chaos"`
}
}
Conf contains the fields stored in the configuration file
func UnmarshalRead ¶
UnmarshalRead reads the unmarshalled config yaml file from disk
func (*Conf) GetKeys ¶
GetKeys gets the API keys from config file and creates a Keys struct We use random selection of api keys from the list of keys supplied. Keys that require 2 options are separated by colon (:).
func (*Conf) MarshalWrite ¶
MarshalWrite writes the marshaled yaml config to disk
Click to show internal directories.
Click to hide internal directories.